from zope.interface import implements
from dateable.chronos.interfaces import IEvent
from Products.ATContentTypes.interfaces import IATEvent
from zope import component

from Products.ATContentTypes.utils import DT2dt

class Event(object):

    implements(IEvent)
    component.adapts(IATEvent)

    def __init__(self, event):
        self.event = event

    def __cmp__(self, other):
        return cmp(self.event.start, other.event.start)

    @property
    def title(self): return self.event.Title()
    @property
    def description(self): return self.event.Description()
    @property
    def start(self): return DT2dt((self.event.start()))
    @property
    def end(self): return DT2dt((self.event.end()))
    @property
    def location(self): return ''
    @property
    def local_url(self): return self.event.absolute_url()
    @property
    def url(self): return self.event.absolute_url()
    @property
    def type(self): return ','.join(self.event.getEventType())
    @property
    def timezone(self): return self.event.start.timezone()

from zope.component import getGlobalSiteManager
gsm = getGlobalSiteManager()
gsm.registerAdapter(Event, (IATEvent,), IEvent, 'CalendarEventAdapter')

try:
    from Products.RadioSchedule.contents.interfaces import IRadioshow

    class RadioEvent(object):

        implements(IEvent)
        component.adapts(IRadioshow)

        def __init__(self, event):
            self.event = event

        def __cmp__(self, other):
            return cmp(self.event.start, other.event.start)

        @property
        def title(self): return self.event.Title()
        @property
        def description(self): return self.event.Description()
        @property
        def start(self): return DT2dt((self.event.start()))
        @property
        def end(self): return DT2dt((self.event.end()))
        @property
        def location(self): return ''
        @property
        def local_url(self): return self.event.absolute_url()
        @property
        def url(self): return self.event.absolute_url()
        @property
        def type(self): return 'Radio show'
        @property
        def timezone(self): return self.event.start.timezone()

    from zope.component import getGlobalSiteManager
    gsm = getGlobalSiteManager()
    gsm.registerAdapter(RadioEvent, (IRadioshow,), IEvent,
                        'RadioshowCalendarEventAdapter')

except ImportError: pass



from Products.CMFCore.permissions import setDefaultRoles
##code-section config-head #fill in your manual code here
##/code-section config-head


PROJECTNAME = "SimpleCalendar"

# Permissions
DEFAULT_ADD_CONTENT_PERMISSION = "Add portal content"
setDefaultRoles(DEFAULT_ADD_CONTENT_PERMISSION, ('Manager', 'Owner'))
ADD_CONTENT_PERMISSIONS = {
    'SimpleCalendar': 'SimpleCalendar: Add SimpleCalendar',
}

setDefaultRoles('SimpleCalendar: Add SimpleCalendar', ('Manager','Owner'))

product_globals = globals()

# Dependencies of Products to be installed by quick-installer
# override in custom configuration
DEPENDENCIES = []

# Dependend products - not quick-installed - used in testcase
# override in custom configuration
PRODUCT_DEPENDENCIES = []

##code-section config-bottom #fill in your manual code here
##/code-section config-bottom


# Load custom configuration not managed by archgenxml
try:
    from Products.SimpleCalendar.AppConfig import *
except ImportError:
    pass



# -*- coding: utf-8 -*-
#
# File: SimpleCalendar.py
#
# Copyright (c) 2008 by 
# Generator: ArchGenXML Version 2.0
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#

__author__ = """unknown <unknown>"""
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
from zope.interface import implements
from dateable.chronos.interfaces import ICalendarEnhanced, IPossibleCalendar, IEvent
from dateable.kalends import IEventProvider

from Products.CMFDynamicViewFTI.browserdefault import BrowserDefaultMixin

from Products.ATReferenceBrowserWidget.ATReferenceBrowserWidget import ReferenceBrowserWidget
from Products.SimpleCalendar import SimpleCalendarMessageFactory as _

from Products.SimpleCalendar.config import *
from Products.CMFCore.utils import getToolByName

from DateTime import DateTime

##code-section module-header #fill in your manual code here
##/code-section module-header

schema = Schema((
    LinesField('item_states',
         widget=LinesWidget(label = _(u'item_states', default=u'Event states to include in calendar, empty means all states')),),
),
)

##code-section after-local-schema #fill in your manual code here
##/code-section after-local-schema

SimpleCalendar_schema = BaseSchema.copy() + \
    schema.copy()

##code-section after-schema #fill in your manual code here
##/code-section after-schema

def filter_exclude_paths(objects, paths):
    """Removes objects with paths."""
    objects_ = []
    for object in objects:
        for path in paths:
            if '/'.join(object.getPhysicalPath()).startswith(path):
                break
        else:
            objects_.append(object)
    return objects_

from dateable.chronos.browser.eventdisplay import EventDisplay
from zope.component import getAdapter

class SimpleCalendar(BaseContent, BrowserDefaultMixin):
    """
    """
    security = ClassSecurityInfo()
    implements(ICalendarEnhanced, IPossibleCalendar, IEventProvider)

    meta_type = 'SimpleCalendar'
    _at_rename_after_creation = True

    schema = SimpleCalendar_schema

    ##code-section class-header #fill in your manual code here
    exclude_from_nav = True    
    ##/code-section class-header

    def getEvents(self, start, stop, EventDisplay=EventDisplay, **kw):
        states = filter(None, self.getItem_states())
        query = {}
        if states:
            query['review_state'] = states
        result = list(map(lambda x: getAdapter(x.getObject(), IEvent,
                          'CalendarEventAdapter',),
                          self.portal_catalog(
                    start={'query':start, 'range':'min'},
                    end={'query':stop, 'range':'max'}, meta_type='ATEvent', **query)))
        return result

    getOccurrences = getEvents

registerType(SimpleCalendar, PROJECTNAME)
# end of class SimpleCalendar

##code-section module-footer #fill in your manual code here
##/code-section module-footer






from dateable.chronos.browser.month import MonthView
from dateable.chronos.browser.week import WeekView
from dateable.chronos.browser.day import DayView
from zope.interface import classImplements
from interfaces import ISimpleViewClass, ISimpleViewClassWeek, ISimpleViewClassWeek, ISimpleViewClassDay

getOccurrenceDisplays = MonthView.getOccurrenceDisplays

def new_getOccurrenceDisplays(self, day):
    classImplements(self.__class__, ISimpleViewClass)
    return getOccurrenceDisplays(self, day)

MonthView.getOccurrenceDisplays = new_getOccurrenceDisplays

getEventDisplays = WeekView.getEventDisplays.im_func

def new_getEventDisplays(self):
    classImplements(self.__class__, ISimpleViewClassWeek)
    try:
        return getEventDisplays(self)
    except Exception, value:
        raise
        import pdb
        pdb.set_trace()

WeekView.getEventDisplays = new_getEventDisplays

DayGetEventDisplays = DayView.getEventDisplays.im_func

def new_getEventDisplays(self):
    classImplements(self.__class__, ISimpleViewClassDay)
    return DayGetEventDisplays(self)

DayView.getEventDisplays = new_getEventDisplays

from dateable.chronos.browser.base_view import BaseCalendarView

old_get_action_url = BaseCalendarView.get_action_url

def get_action_url(self, action):
    url = old_get_action_url(self, action)
    if not url.startswith('/') or url.startswith('http://') \
            or url.startswith('https://'):
        return self.context.absolute_url() + '/' + action
    else:
        return action

BaseCalendarView.get_action_url = get_action_url




from Products.Archetypes import listTypes
from Products.CMFCore import utils as cmfutils

from Products.Archetypes.atapi import *
from config import PROJECTNAME, DEFAULT_ADD_CONTENT_PERMISSION, ADD_CONTENT_PERMISSIONS

def initialize(context):
    """initialize product (called by zope)"""
    ##code-section custom-init-top #fill in your manual code here
    ##/code-section custom-init-top

    # imports packages and types for registration
    import content


    # Initialize portal content
    all_content_types, all_constructors, all_ftis = process_types(
        listTypes(PROJECTNAME),
        PROJECTNAME)

    cmfutils.ContentInit(
        PROJECTNAME + ' Content',
        content_types      = all_content_types,
        permission         = DEFAULT_ADD_CONTENT_PERMISSION,
        extra_constructors = all_constructors,
        fti                = all_ftis,
        ).initialize(context)

    # Give it some extra permissions to control them on a per class limit
    for i in range(0,len(all_content_types)):
        klassname=all_content_types[i].__name__
        if not klassname in ADD_CONTENT_PERMISSIONS:
            continue

        context.registerClass(meta_type   = all_ftis[i]['meta_type'],
                              constructors= (all_constructors[i],),
                              permission  = ADD_CONTENT_PERMISSIONS[klassname])

    ##code-section custom-init-bottom #fill in your manual code here
    ##/code-section custom-init-bottom

import hacks



from setuptools import setup, find_packages
import os

version = '1.0a2'

setup(name='Products.SimpleCalendar',
      version=version,
      description="Simple to install and use calendaring solution",
      long_description=open(os.path.join("Products", "SimpleCalendar", "readme.txt")).read() + '\n\n' + \
          open(os.path.join("Products", "SimpleCalendar", "changes.txt")).read(),
      # Get more strings from
      # http://pypi.python.org/pypi?:action=list_classifiers
      classifiers=[
        "Programming Language :: Python",
        "Development Status :: 3 - Alpha",
        "Environment :: Web Environment",
        "Framework :: Plone :: 4.1",
        "Operating System :: OS Independent",
        "Topic :: Office/Business :: Groupware",
        "Topic :: Office/Business :: Scheduling",
        ],
      keywords='python zope plone calendaring calendar events',
      author='Morten W. Petersen',
      author_email='info@nidelven-it.no',
      url='http://www.nidelven-it.no/d',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['Products'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          'p4a.z2utils==1.0.2', # For IDynamicallyViewable patch
          'p4a.common==1.0.8', # for dateable.chronos eventdisplay.py
          'dateable.chronos', # No version specified here, not sure
          'dateable.kalends', # what other products might use it
          # -*- Extra requirements: -*-
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      )
